@@ -11,12 +11,12 @@ pygame.mixer.init()
 pygame.init()
 
 #Location of the Vuvuzela Wav file
-vuvusound = pygame.mixer.Sound("/opt/vuvuzela/sounds/V.wav")
+vuvusound = pygame.mixer.Sound("/opt/Vuvuzela/sounds/V.wav")
 
 #Definitions to set up the sound playing
 def playSong():
     print "Vuvu Started!"
-    vuvusound.play()
+    vuvusound.play(loops=3, maxtime=0, fade_ms=0)
     time.sleep(.1)
     
 def stopSong():
@@ -39,7 +39,7 @@ class Vuvuzela(QtGui.QWidget):
         
         self.square.setStyleSheet("QWidget { background-color: %s }" % self.color.name())
 
-        vuvupic = QtGui.QPixmap("/opt/vuvuzela/images/vuvuzela.png")
+        vuvupic = QtGui.QPixmap("/opt/Vuvuzela/images/Vuvuzela.png")
         label = QtGui.QLabel(self)
         label.setPixmap(vuvupic)
         label.move(103, 100)
